macro_rules! failspot_name {
($($t: tt)*) => { ... };
}Expand description
Declares an enum that can be used as a name for a failspot
When feature enabled is off, this macro does nothing.
See the crate-level docs for details.
macro_rules! failspot_name {
($($t: tt)*) => { ... };
}Declares an enum that can be used as a name for a failspot
When feature enabled is off, this macro does nothing.
See the crate-level docs for details.